import { app, BrowserWindow, Menu, ipcMain } from 'electron'
import fs from 'fs'
import request from 'request'

/**
 * Set `__static` path to static files in production
 * https://simulatedgreg.gitbooks.io/electron-vue/content/en/using-static-assets.html
 */
if (process.env.NODE_ENV !== 'development') {
    global.__static = require('path').join(__dirname, '/static').replace(/\\/g, '\\\\')
}

ipcMain.on('get-messages', (event) => {
    request('http://127.0.0.1:5000/', function(error, response, body) {
        event.sender.send('set-messages', JSON.parse(body))
    })
})

let mainWindow

const winURL = process.env.NODE_ENV === 'development' ?
    `http://localhost:9080` :
    `file://${__dirname}/index.html`

const createWindow = () => {
    mainWindow = new BrowserWindow({
        height: 630,
        width: 1100,
        frame: false
    })

    mainWindow.maximize()

    mainWindow.loadURL(winURL)

    mainWindow.on('closed', () => {
        mainWindow = null
    })

    Menu.setApplicationMenu(null)
}

app.on('ready', createWindow)

app.on('window-all-closed', () => {
    if (process.platform !== 'darwin') {
        app.quit()
    }
})

app.on('activate', () => {
    if (mainWindow === null) {
        createWindow()
    }
})